@@ -371,6 +371,9 @@ _rsvg_acquire_xlink_href_resource (const char *href,
 {
 	GByteArray * arr = NULL;
 
+	if(!(href && *href))
+		return NULL;
+
 	if(!strncmp(href, "data:", 5))
 		arr = rsvg_acquire_base64_resource (href, err);
 	
@@ -503,12 +506,15 @@ rsvg_node_image_draw (RsvgNode * self, RsvgDrawingCtx *ctx,
 	RsvgNodeImage *z = (RsvgNodeImage *)self;
 	unsigned int aspect_ratio = z->preserve_aspect_ratio;
 	GdkPixbuf *img = z->img;
+	gdouble x, y, w, h;
+
 	if (img == NULL)
 		return;
-	gdouble x = _rsvg_css_normalize_length(&z->x, ctx, 'h');
-	gdouble y = _rsvg_css_normalize_length(&z->y, ctx, 'v');
-	gdouble w = _rsvg_css_normalize_length(&z->w, ctx, 'h');
-	gdouble h = _rsvg_css_normalize_length(&z->h, ctx, 'v');
+
+	x = _rsvg_css_normalize_length(&z->x, ctx, 'h');
+	y = _rsvg_css_normalize_length(&z->y, ctx, 'v');
+	w = _rsvg_css_normalize_length(&z->w, ctx, 'h');
+	h = _rsvg_css_normalize_length(&z->h, ctx, 'v');
 
 	rsvg_state_reinherit_top(ctx, z->super.state, dominate);
 
@@ -550,8 +556,11 @@ rsvg_node_image_set_atts (RsvgNode *self, RsvgHandle *ctx, RsvgPropertyBag *atts
 															rsvg_handle_get_base_uri (ctx), 
 															NULL); 
 					
-					if (!image->img)
+					if (!image->img) {
+#ifdef G_ENABLE_DEBUG
 						g_warning (_("Couldn't load image: %s\n"), value);
+#endif
+					}
 				}
 			if ((value = rsvg_property_bag_lookup (atts, "class")))
 				klazz = value;
