@@ -27,10 +27,13 @@
 #define RSVG_TEXT_H
 
 #include "rsvg.h"
+#include "rsvg-shapes.h"
 
 G_BEGIN_DECLS
 
-void rsvg_start_text (RsvgHandle *ctx, RsvgPropertyBag *atts);
+RsvgNode * rsvg_new_text (void);
+RsvgNode * rsvg_new_tspan (void);
+RsvgNode * rsvg_new_tref (void);
 char * rsvg_make_valid_utf8 (const char *str);
 
 G_END_DECLS
